from setuptools import setup, find_packages
from activecampaign_api.version import __version__

setup(
    name='activecampaign_api',
    version=__version__,
    packages=find_packages(),
    url='',
    license='',
    author='Yevhen Pechurin',
    author_email='yevhen.pechurin@gmail.com',
    description='Api for activecampaign'
)
